@@ -226,10 +226,8 @@ class AbstractInversion:
 
     @property
     def brightest_reconstruction_pixel_centre(self):
-        return grids.GridCoordinates(
-            coordinates=[
-                self.mapper.pixelization_grid[self.brightest_reconstruction_pixel]
-            ]
+        return grids.GridIrregular(
+            grid=[self.mapper.pixelization_grid[self.brightest_reconstruction_pixel]]
         )
 
 
@@ -551,26 +549,20 @@ class InversionInterferometerMatrix(
         settings=SettingsInversion(),
     ):
 
-        transformed_mapping_matrices = (
-            transformer.transformed_mapping_matrices_from_mapping_matrix(
-                mapping_matrix=mapper.mapping_matrix
-            )
+        transformed_mapping_matrices = transformer.transformed_mapping_matrices_from_mapping_matrix(
+            mapping_matrix=mapper.mapping_matrix
         )
 
-        real_data_vector = (
-            inversion_util.data_vector_via_transformed_mapping_matrix_from(
-                transformed_mapping_matrix=transformed_mapping_matrices[0],
-                visibilities=visibilities[:, 0],
-                noise_map=noise_map[:, 0],
-            )
+        real_data_vector = inversion_util.data_vector_via_transformed_mapping_matrix_from(
+            transformed_mapping_matrix=transformed_mapping_matrices[0],
+            visibilities=visibilities[:, 0],
+            noise_map=noise_map[:, 0],
         )
 
-        imag_data_vector = (
-            inversion_util.data_vector_via_transformed_mapping_matrix_from(
-                transformed_mapping_matrix=transformed_mapping_matrices[1],
-                visibilities=visibilities[:, 1],
-                noise_map=noise_map[:, 1],
-            )
+        imag_data_vector = inversion_util.data_vector_via_transformed_mapping_matrix_from(
+            transformed_mapping_matrix=transformed_mapping_matrices[1],
+            visibilities=visibilities[:, 1],
+            noise_map=noise_map[:, 1],
         )
 
         real_curvature_matrix = inversion_util.curvature_matrix_via_mapping_matrix_from(
@@ -591,12 +583,10 @@ class InversionInterferometerMatrix(
 
         if settings.use_preconditioner:
 
-            preconditioner_matrix = (
-                inversion_util.preconditioner_matrix_via_mapping_matrix_from(
-                    mapping_matrix=mapper.mapping_matrix,
-                    regularization_matrix=regularization_matrix,
-                    preconditioner_noise_normalization=np.sum(1.0 / noise_map ** 2),
-                )
+            preconditioner_matrix = inversion_util.preconditioner_matrix_via_mapping_matrix_from(
+                mapping_matrix=mapper.mapping_matrix,
+                regularization_matrix=regularization_matrix,
+                preconditioner_noise_normalization=np.sum(1.0 / noise_map ** 2),
             )
 
             preconditioner_inv = np.linalg.inv(preconditioner_matrix)
@@ -742,14 +732,12 @@ class InversionInterferometerLinearOperator(AbstractInversionInterferometer):
             regularization_matrix=regularization_matrix, dtype="float64"
         )
 
-        preconditioner_matrix = (
-            inversion_util.preconditioner_matrix_via_mapping_matrix_from(
-                mapping_matrix=mapper.mapping_matrix,
-                regularization_matrix=regularization_matrix,
-                preconditioner_noise_normalization=np.sum(
-                    np.divide(1.0, np.square(noise_map))
-                ),
-            )
+        preconditioner_matrix = inversion_util.preconditioner_matrix_via_mapping_matrix_from(
+            mapping_matrix=mapper.mapping_matrix,
+            regularization_matrix=regularization_matrix,
+            preconditioner_noise_normalization=np.sum(
+                np.divide(1.0, np.square(noise_map))
+            ),
         )
 
         log_det_curvature_reg_matrix_term = 2.0 * np.sum(
