@@ -251,7 +251,7 @@ class RegularizationLop(pylops.LinearOperator):
         self.explicit = False
 
     def _matvec(self, x):
-        return x
+        return np.dot(self.regularization_matrix, x)
 
     def _rmatvec(self, x):
-        return self.regularization_matrix
+        return np.dot(self.regularization_matrix.T, x)
