@@ -4,9 +4,8 @@ import copy
 import numpy as np
 
 from autoarray import exc
-from autoarray.structures import abstract_structure
 from autoarray.mask import abstract_mask
-from autoarray.util import array_util, binning_util, mask_util
+from autoarray.util import array_util, binning_util, geometry_util, mask_util
 from autoarray.structures import arrays
 
 logging.basicConfig()
@@ -263,9 +262,7 @@ class Mask2D(AbstractMask2D):
         if invert:
             mask = np.invert(mask)
 
-        pixel_scales = abstract_structure.convert_pixel_scales(
-            pixel_scales=pixel_scales
-        )
+        pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
         if len(mask.shape) != 2:
             raise exc.MaskException("The input mask is not a two dimensional array")
