@@ -213,6 +213,12 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
             visibilities_1d=np.stack((visibilities.real, visibilities.imag), axis=-1)
         )
 
+    def image_from_visibilities(self, visibilities):
+        visibilities = visibilities[:, 0] + 1j * visibilities[:, 1]
+        # ...
+        image = self.adjoint(visibilities)
+        return image.real
+
     def transformed_mapping_matrices_from_mapping_matrix(self, mapping_matrix):
 
         real_transfomed_mapping_matrix = np.zeros(
@@ -265,7 +271,7 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
                     with the size of Nd or Nd + (batch, )
         :rtype: numpy array with the dtype of numpy.complex64
         """
-        x = self.xx2x(self.k2xx(self.y2k(y)))
+        x = np.real(self.xx2x(self.k2xx(self.y2k(y))))
         return array_util.sub_array_complex_1d_from(
             sub_array_2d=x[::-1, :], sub_size=1, mask=self.real_space_mask
         )
