@@ -176,7 +176,9 @@ class VisibilitiesNoiseMap(Visibilities):
             np.divide(1.0, np.square(visibilities_1d))
         )
 
-        obj.Wop = pylops.Diagonal(1.0 / np.real(obj).ravel(), dtype="complex128")
+        obj.Wop = pylops.Diagonal(
+            1.0 / np.real(obj).ravel(), dtype="complex128"
+        )
         return obj
 
     def __array_finalize__(self, obj):
