@@ -97,18 +97,14 @@ class TestDataVectorFromData:
         data = np.array([4.0, 1.0, 1.0, 16.0, 1.0, 1.0])
         noise_map = np.array([2.0, 1.0, 1.0, 4.0, 1.0, 1.0])
 
-        data_vector_via_blurred = (
-            aa.util.inversion.data_vector_via_blurred_mapping_matrix_from(
-                blurred_mapping_matrix=mapping_matrix, image=data, noise_map=noise_map
-            )
+        data_vector_via_blurred = aa.util.inversion.data_vector_via_blurred_mapping_matrix_from(
+            blurred_mapping_matrix=mapping_matrix, image=data, noise_map=noise_map
         )
 
-        data_vector_via_transformed = (
-            aa.util.inversion.data_vector_via_transformed_mapping_matrix_from(
-                transformed_mapping_matrix=mapping_matrix,
-                visibilities=data,
-                noise_map=noise_map,
-            )
+        data_vector_via_transformed = aa.util.inversion.data_vector_via_transformed_mapping_matrix_from(
+            transformed_mapping_matrix=mapping_matrix,
+            visibilities=data,
+            noise_map=noise_map,
         )
 
         assert (data_vector_via_blurred == data_vector_via_transformed).all()
@@ -180,16 +176,12 @@ class TestCurvatureMatrixFromBlurred:
 
         noise_map = np.array([2.0, 1.0, 1.0, 4.0, 1.0, 1.0])
 
-        curvature_matrix_via_blurred = (
-            aa.util.inversion.curvature_matrix_via_mapping_matrix_from(
-                mapping_matrix=mapping_matrix, noise_map=noise_map
-            )
+        curvature_matrix_via_blurred = aa.util.inversion.curvature_matrix_via_mapping_matrix_from(
+            mapping_matrix=mapping_matrix, noise_map=noise_map
         )
 
-        curvature_matrix_via_transformed = (
-            aa.util.inversion.curvature_matrix_via_mapping_matrix_from(
-                mapping_matrix=mapping_matrix, noise_map=noise_map
-            )
+        curvature_matrix_via_transformed = aa.util.inversion.curvature_matrix_via_mapping_matrix_from(
+            mapping_matrix=mapping_matrix, noise_map=noise_map
         )
 
         assert (curvature_matrix_via_blurred == curvature_matrix_via_transformed).all()
@@ -407,12 +399,10 @@ class TestPreconditionerMatrix:
             ]
         )
 
-        preconditioner_matrix = (
-            aa.util.inversion.preconditioner_matrix_via_mapping_matrix_from(
-                mapping_matrix=mapping_matrix,
-                preconditioner_noise_normalization=1.0,
-                regularization_matrix=np.zeros((3, 3)),
-            )
+        preconditioner_matrix = aa.util.inversion.preconditioner_matrix_via_mapping_matrix_from(
+            mapping_matrix=mapping_matrix,
+            preconditioner_noise_normalization=1.0,
+            regularization_matrix=np.zeros((3, 3)),
         )
 
         assert (
@@ -420,12 +410,10 @@ class TestPreconditionerMatrix:
             == np.array([[2.0, 0.0, 0.0], [0.0, 2.0, 0.0], [0.0, 0.0, 2.0]])
         ).all()
 
-        preconditioner_matrix = (
-            aa.util.inversion.preconditioner_matrix_via_mapping_matrix_from(
-                mapping_matrix=mapping_matrix,
-                preconditioner_noise_normalization=2.0,
-                regularization_matrix=np.zeros((3, 3)),
-            )
+        preconditioner_matrix = aa.util.inversion.preconditioner_matrix_via_mapping_matrix_from(
+            mapping_matrix=mapping_matrix,
+            preconditioner_noise_normalization=2.0,
+            regularization_matrix=np.zeros((3, 3)),
         )
 
         assert (
@@ -437,12 +425,10 @@ class TestPreconditionerMatrix:
             [[1.0, 2.0, 3.0], [4.0, 5.0, 6.0], [7.0, 8.0, 9.0]]
         )
 
-        preconditioner_matrix = (
-            aa.util.inversion.preconditioner_matrix_via_mapping_matrix_from(
-                mapping_matrix=mapping_matrix,
-                preconditioner_noise_normalization=2.0,
-                regularization_matrix=regularization_matrix,
-            )
+        preconditioner_matrix = aa.util.inversion.preconditioner_matrix_via_mapping_matrix_from(
+            mapping_matrix=mapping_matrix,
+            preconditioner_noise_normalization=2.0,
+            regularization_matrix=regularization_matrix,
         )
 
         assert (
