@@ -11,9 +11,10 @@ class TestRectangular:
             # I3I4I5I
             # I6I7I8I
 
-            pixel_neighbors, pixel_neighbors_size = aa.util.pixelization.rectangular_neighbors_from(
-                shape_2d=(3, 3)
-            )
+            (
+                pixel_neighbors,
+                pixel_neighbors_size,
+            ) = aa.util.pixelization.rectangular_neighbors_from(shape_2d=(3, 3))
 
             assert (pixel_neighbors[0] == [1, 3, -1, -1]).all()
             assert (pixel_neighbors[1] == [0, 2, 4, -1]).all()
@@ -33,9 +34,10 @@ class TestRectangular:
             # I4I5I 6I 7I
             # I8I9I10I11I
 
-            pixel_neighbors, pixel_neighbors_size = aa.util.pixelization.rectangular_neighbors_from(
-                shape_2d=(3, 4)
-            )
+            (
+                pixel_neighbors,
+                pixel_neighbors_size,
+            ) = aa.util.pixelization.rectangular_neighbors_from(shape_2d=(3, 4))
 
             assert (pixel_neighbors[0] == [1, 4, -1, -1]).all()
             assert (pixel_neighbors[1] == [0, 2, 5, -1]).all()
@@ -61,9 +63,10 @@ class TestRectangular:
             # I6I 7I 8I
             # I9I10I11I
 
-            pixel_neighbors, pixel_neighbors_size = aa.util.pixelization.rectangular_neighbors_from(
-                shape_2d=(4, 3)
-            )
+            (
+                pixel_neighbors,
+                pixel_neighbors_size,
+            ) = aa.util.pixelization.rectangular_neighbors_from(shape_2d=(4, 3))
 
             assert (pixel_neighbors[0] == [1, 3, -1, -1]).all()
             assert (pixel_neighbors[1] == [0, 2, 4, -1]).all()
@@ -89,9 +92,10 @@ class TestRectangular:
             # I8 I 9I10I11I
             # I12I13I14I15I
 
-            pixel_neighbors, pixel_neighbors_size = aa.util.pixelization.rectangular_neighbors_from(
-                shape_2d=(4, 4)
-            )
+            (
+                pixel_neighbors,
+                pixel_neighbors_size,
+            ) = aa.util.pixelization.rectangular_neighbors_from(shape_2d=(4, 4))
 
             assert (pixel_neighbors[0] == [1, 4, -1, -1]).all()
             assert (pixel_neighbors[1] == [0, 2, 5, -1]).all()
@@ -125,7 +129,10 @@ class TestVoronoi:
             )
 
             voronoi = scipy.spatial.Voronoi(points, qhull_options="Qbb Qc Qx Qm")
-            pixel_neighbors, pixel_neighbors_size = aa.util.pixelization.voronoi_neighbors_from(
+            (
+                pixel_neighbors,
+                pixel_neighbors_size,
+            ) = aa.util.pixelization.voronoi_neighbors_from(
                 pixels=5, ridge_points=np.array(voronoi.ridge_points)
             )
 
@@ -156,7 +163,10 @@ class TestVoronoi:
             )
 
             voronoi = scipy.spatial.Voronoi(points, qhull_options="Qbb Qc Qx Qm")
-            pixel_neighbors, pixel_neighbors_size = aa.util.pixelization.voronoi_neighbors_from(
+            (
+                pixel_neighbors,
+                pixel_neighbors_size,
+            ) = aa.util.pixelization.voronoi_neighbors_from(
                 pixels=9, ridge_points=np.array(voronoi.ridge_points)
             )
 
